@@ -10,6 +10,8 @@ from django.conf import settings
 from django.template.defaultfilters import slugify
 from django.utils.datastructures import SortedDict
 
+from .templatetags import redis_metrics_filters as template_tags
+
 
 class R(object):
 
@@ -147,7 +149,10 @@ class R(object):
     def get_metrics(self, slug_list):
         """Get the metrics for multiple slugs.
 
-        Returns a list of dicts.
+        Returns a list of two-tuples containing the metric slug and a
+        dictionary like the one returned by ``get_metric``::
+
+            (some-metric, {'day': 0, 'week': 0, 'month': 0, 'year': 0})
 
         NOTE: This method calls ``get_metric`` for each slug in the
         ``slug_list``, which really isn't very efficient.
@@ -155,12 +160,13 @@ class R(object):
         """
         results = []
         for slug in slug_list:
-            results.append({slug: self.get_metric(slug)})
+            results.append((slug, self.get_metric(slug)))
         return results
 
-    def get_metric_history(self, slug, since=None, granularity='daily'):
-        """Get history for a metric.
+    def get_metric_history(self, slugs, since=None, granularity='daily'):
+        """Get history for one or more metrics.
 
+        * ``slugs`` -- a slug OR a list of slugs
         * ``since`` -- the date from which we start pulling metrics
         * ``granularity`` -- daily, weekly, monthly, yearly
 
@@ -173,12 +179,73 @@ class R(object):
                 ('m:test:w:52', '15'),
             ]
 
+        To get history for multiple metrics, just provide a list of slugs::
+
+            metrics = ['test', 'other']
+            r.get_metric_history(metrics, granularity='weekly')
+            [
+                ('m:test:w:52', '15'),
+                ('m:other:w:52', '42'),
+            ]
+
         """
-        keys = set()  # redis keys
-        for date in self._date_range(since):
-            keys.update(set(self._build_keys(slug, date, granularity)))
+        if not type(slugs) == list:
+            slugs = [slugs]
+
+        # Build the set of Redis keys that we need to get.
+        keys = set()
+        for slug in slugs:
+            for date in self._date_range(since):
+                keys.update(set(self._build_keys(slug, date, granularity)))
         return sorted(zip(keys, self.r.mget(keys)))
 
+    def get_metric_history_as_columns(self, slugs, since=None,
+                                      granularity='daily'):
+        """Provides the same data as ``get_metric_history``, but in a columnar
+        format. If you had the following yearly history, for example::
+
+            [
+                ('m:bar:y:2012', '1'),
+                ('m:bar:y:2013', '2'),
+                ('m:foo:y:2012', '3'),
+                ('m:foo:y:2013', '4')
+            ]
+
+        this method would provide you with the following data structure::
+
+            [
+                ['Period',  'bar',  'foo']
+                ['y:2012',  '1',    '3'],
+                ['y:2013',  '2',    '4'],
+            ]
+
+        Note that this also includes a header column. Data in this format may
+        be useful for certain graphing libraries (I'm looking at you Google
+        Charts LineChart).
+
+        """
+        history = self.get_metric_history(slugs, since, granularity)
+        _history = []  # new, columnar history
+        periods = ['Period']  # A separate, single column for the time period
+        for s in slugs:
+            column = [s]  # story all the data for a single slug
+            for key, value in history:
+                # ``metric_slug`` extracts the slug from the Redis Key
+                if template_tags.metric_slug(key) == s:
+                    column.append(value)
+
+                # Get time period value as first column; This value is
+                # duplicated in the Redis key for each value, so this is a bit
+                # inefficient, but... oh well.
+                period = template_tags.strip_metric_prefix(key)
+                if period not in periods:
+                    periods.append(period)
+
+            _history.append(column)  # Remember that slug's column of data
+        _history.insert(0, periods)  # Finally, stick the time periods in the
+                                     # first column.
+        return zip(*_history)  # Transpose the rows & columns
+
     # Gauges. Gauges have a different prefix "g:" in order to differentiate
     # them from a metric of the same name.
     def gauge_slugs(self):
